sqltriples.Adapter

Module sqltriples :: Class Adapter |
[show private | hide private]
[frames | no frames]

## Class Adapter

Known Subclasses:
  `PgSQLAdapter`, `pysqlite2Adapter`

Method Summary
| `__init__(self, connection)`
| `delete_sequence(self, cursor, sequence_name)`
| `delete_table(self, cursor, table_name)`
| `init_sequence(self, cursor, sequence_name)`
| `init_table(self, cursor, table_name)`
| `query_next_bnode_id(self, cursor, sequence_name)`
| `_pmark(self, i)`
| `_present(self, values)`

Class Variable Summary
`dict` | `_paramdict` = `{'named': 1, 'format': 0, 'pyformat': 1, 'n...`

Class Variable Details

    ### _paramdict Type: `dict` Value:
        {'named': 1, 'format': 0, 'pyformat': 1, 'numeric': 0, 'qmark': 0}

Generated by Epydoc 2.1 on Fri Mar 31 17:48:37 2006 | http://epydoc.sf.net